@@ -1,22 +1,8 @@
-﻿/*
- *  Copyright 2011-2014  Andreas Cord-Landwehr <cordlandwehr@kde.org>
- *  Copyright 2019       Caio Henrique Segawa Tonetti <caio.tonetti@gmail.com>
+/*
+ *  SPDX-FileCopyrightText: 2011-2014 Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  SPDX-FileCopyrightText: 2019 Caio Henrique Segawa Tonetti <caio.tonetti@gmail.com>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) version 3, or any
- *  later version accepted by the membership of KDE e.V. (or its
- *  successor approved by the membership of KDE e.V.), which shall
- *  act as a proxy defined in Section 6 of version 3 of the license.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "generategraphwidget.h"
@@ -268,9 +254,10 @@ QPointF GenerateGraphWidget::documentCenter() const
     QPointF center = QPointF(geometry().center());
     qreal xSum = 0;
     qreal ySum = 0;
-    int number = m_document->nodes().length();
+    const auto documentNodes = m_document->nodes();
+    int number = documentNodes.size();
 
-    foreach (NodePtr node, m_document->nodes()) {
+    for (const NodePtr &node : documentNodes) {
         xSum += node->x();
         ySum += node->y();
     }
